/*
==--==--==--==--==--==--==--==--==--==--==--==--==--==--==--==--

Dia-Args

Copyright (C) 2018-2019, 2021-2023  Anonymous

There are several releases over multiple years,
they are listed as ranges, such as: "2018-2019".

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.

::--::--::--::--::--::--::--::--::--::--::--::--::--::--::--::--
*/

//! # Template type

use {
    core::{
        fmt,
        str::FromStr,
    },
    std::io::{Error, ErrorKind},
};

const LIB: &str = "lib";
const BIN: &str = "bin";

/// # Template type
#[derive(Debug, Eq, PartialEq)]
pub enum TemplateType {

    /// # Library
    LIB,

    /// # Binary
    BIN,

}

impl FromStr for TemplateType {

    type Err = Error;

    fn from_str(s: &str) -> Result<Self, Self::Err> {
        match s {
            self::LIB => Ok(TemplateType::LIB),
            self::BIN => Ok(TemplateType::BIN),
            _ => Err(Error::new(ErrorKind::InvalidInput, format!("Unknown template type: {:?}", s))),
        }
    }

}

impl fmt::Display for TemplateType {

    fn fmt(&self, f: &mut fmt::Formatter) -> Result<(), fmt::Error> {
        f.write_str(match self {
            TemplateType::LIB => LIB,
            TemplateType::BIN => BIN,
        })
    }

}
